==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/AzureFileVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class AzureFileVolumeSourceBuilder extends AzureFileVolumeSourceFluentImpl<AzureFileVolumeSourceBuilder> implements VisitableBuilder<AzureFileVolumeSource,AzureFileVolumeSourceBuilder>{

    AzureFileVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public AzureFileVolumeSourceBuilder(){
            this(true);
    }
    public AzureFileVolumeSourceBuilder(Boolean validationEnabled){
            this(new AzureFileVolumeSource(), validationEnabled);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new AzureFileVolumeSource(), validationEnabled);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance){
            this(fluent, instance, true);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withReadOnly(instance.getReadOnly()); 
            fluent.withSecretName(instance.getSecretName()); 
            fluent.withShareName(instance.getShareName()); 
            this.validationEnabled = validationEnabled; 
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance){
            this(instance,true);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withReadOnly(instance.getReadOnly()); 
            this.withSecretName(instance.getSecretName()); 
            this.withShareName(instance.getShareName()); 
            this.validationEnabled = validationEnabled; 
    }

    public AzureFileVolumeSource build(){
            AzureFileVolumeSource buildable = new AzureFileVolumeSource(fluent.isReadOnly(),fluent.getSecretName(),fluent.getShareName());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AzureFileVolumeSourceBuilder that = (AzureFileVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-2.0.4-sources.jar: io/fabric8/kubernetes/api/model/AzureFileVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class AzureFileVolumeSourceBuilder extends AzureFileVolumeSourceFluentImpl<AzureFileVolumeSourceBuilder> implements VisitableBuilder<AzureFileVolumeSource,AzureFileVolumeSourceBuilder>{

    AzureFileVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public AzureFileVolumeSourceBuilder(){
            this(true);
    }
    public AzureFileVolumeSourceBuilder(Boolean validationEnabled){
            this(new AzureFileVolumeSource(), validationEnabled);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new AzureFileVolumeSource(), validationEnabled);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance){
            this(fluent, instance, true);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSourceFluent<?> fluent,AzureFileVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withReadOnly(instance.getReadOnly()); 
            fluent.withSecretName(instance.getSecretName()); 
            fluent.withShareName(instance.getShareName()); 
            this.validationEnabled = validationEnabled; 
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance){
            this(instance,true);
    }
    public AzureFileVolumeSourceBuilder(AzureFileVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withReadOnly(instance.getReadOnly()); 
            this.withSecretName(instance.getSecretName()); 
            this.withShareName(instance.getShareName()); 
            this.validationEnabled = validationEnabled; 
    }

    public AzureFileVolumeSource build(){
            AzureFileVolumeSource buildable = new AzureFileVolumeSource(fluent.isReadOnly(),fluent.getSecretName(),fluent.getShareName());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            AzureFileVolumeSourceBuilder that = (AzureFileVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
